@@ -36,7 +36,7 @@ class ControllerAPI:
         self.async_response_wait_time_sec = async_response_sec
         
         # Tunable to determine how long to wait for a result before declaring timeout
-        self.max_result_waittime = 120 # seconds
+        self.max_result_waittime = 20 # seconds
         self.max_iteration_check = int(self.max_result_waittime / async_response_sec)
         
         # How many times to try POST to Pelion
@@ -152,9 +152,13 @@ class ControllerAPI:
     #
     
     # Get Configuration
-    def pelion_get_config(self):
+    def pelion_get_config(self, key=None):
         req_id = str(uuid.uuid4())
-        return self.__pelion_get(req_id,self.pelion_config_lwm2m_uri)
+        my_config = self.__pelion_get(req_id,self.pelion_config_lwm2m_uri)
+        if key == None:
+            return my_config
+        else:
+            return my_config['config'][key]
 
     # Set Configuration
     def pelion_set_config(self,key,value):
